@@ -200,12 +200,12 @@ class KeySignatureEngraver(Engraver):
                     'bes': 2, 'aes': 3, 'ges': 4, 'fes': 5,
                     'gis': -3, 'fis': -2, 'eis': -1, 'dis': 0,
                     'cis': 1, 'bis': 2, 'ais': 3}[acc]
-            elif self.m_clef == 'violin':
+            elif self.m_clef == 'violin' or self.m_clef == 'treble':
                 ypos = {'gis': -5, 'fis': -4, 'eis': -3, 'dis': -2, 'cis': -1,
                     'bis': 0, 'ais': 1, 'ees': -3, 'des': -2, 'ces': -1,
                     'bes': 0, 'aes': 1, 'ges': 2, 'fes': 3}[acc]
             else:
-                raise "unknown clef"
+                raise "unknown clef:", self.m_clef
             if acc in ['ces', 'des', 'ees', 'fes', 'ges', 'aes', 'bes']:
                 type = -1
             else:
