@@ -241,7 +241,7 @@ class ConfigWindow(gnome.ui.GnomePropertyBox, cfg.ConfigUtils):
         self.g_device_entry.set_text(self.get_string('sound/device_file'))
         self.g_synth_num = gtk.GtkSpinButton(gtk.GtkAdjustment(0, 0, 100, 1, 1),
                              digits=0)
-        self.g_synth_num.set_value(self.get_int('sound/synth_num'))
+        self.g_synth_num.set_value(self.get_int('sound/synth_number'))
         hbox.pack_start(combo, gtk.FALSE)
         hbox.pack_start(self.g_synth_num, gtk.FALSE)
 
@@ -395,7 +395,7 @@ class ConfigWindow(gnome.ui.GnomePropertyBox, cfg.ConfigUtils):
             self.set_string("sound/device_file", self.g_device_entry.get_text())
             self.set_string("sound/card_info", card_info)
             if soundcard.synth.m_type_major == "OSS":
-                self.set_int("sound/synth_num", soundcard.synth.m_devnum)
+                self.set_int("sound/synth_number", soundcard.synth.m_devnum)
                 # we set the spin just in case m_devnum was changed by the
                 # soundcard setup code, if it was out of range
                 self.g_synth_num.set_value(soundcard.synth.m_devnum)
