@@ -43,6 +43,7 @@ class Gui(abstract.LessonbasedGui):
         ################
         # practise_box #
         ################
+        self.g_question_title = gu.bLabel(self.practise_box, "")
         self.g_music_displayer = mpd.musicdisplayer.MusicDisplayer()
         self.g_music_displayer.set_usize(-1, 150)
         self.g_music_displayer.show()
@@ -77,11 +78,11 @@ class Gui(abstract.LessonbasedGui):
     def select_previous(self, widget):
         self.m_t.m_P.select_previous()
         self.display_start_of_music()
-        self.update_partview()
+        self._update()
     def select_next(self, widget):
         self.m_t.m_P.select_next()
         self.display_start_of_music()
-        self.update_partview()
+        self._update()
     def play(self, widget=None):
         self.m_t.play_question()
     def on_end_practise(self):
@@ -90,12 +91,13 @@ class Gui(abstract.LessonbasedGui):
         if self.m_t.m_P:
             self.g_music_displayer.display(self.m_t.m_P.get_music(), 
                             self.get_int('config/feta_font_size=20'))
-    def update_partview(self):
+    def _update(self):
         """
         Updates the buttons above the action_area where you have
         one or more buttons with a small note pixmap on. Each of the
         buttons will play one part of the music in the question.
         """
+        self.g_question_title.set_text(self.m_t.m_P.get_name())
         # tmp func used as callback function
         def f(w, start, end, self=self):
             track = mpd.music_to_track(self.m_t.m_P.get_music(), start, end)
@@ -145,7 +147,7 @@ class Gui(abstract.LessonbasedGui):
         else:
             self.action_area.set_sensitive(gtk.FALSE)
             self.g_music_displayer.clear()
-        self.update_partview()
+        self._update()
         self.g_win.set_title("Solfege - " + self.get_pretty_name())
     def create_pixmap_button(self):
         pix, mask = gtk.create_pixmap_from_xpm(self, None,
