@@ -116,7 +116,7 @@ class Gui(abstract.LessonbasedGui):
         self.update_gui_after_lessonfile_change()
     def show_answer(self, widget=None):
         if self.m_t.q_status in (const.QSTATUS_SOLVED, const.QSTATUS_GIVE_UP):
-            self.m_t.m_app.display_in_musicviewer(self.m_t.m_P.get_music())
+            self.g_win.display_in_musicviewer(self.m_t.m_P.get_music())
     def update_answer_buttons(self):
         if self.m_t.m_P:
             self.g_bb.initialize(self.m_t.m_P.header.fillnum,
