@@ -15,12 +15,59 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
+# random has to be imported before gtk on win32
+import random
 import sys, time
-import app
 from i18n import _
 import configureoutput
 
-app.do_some_cmdline_options(sys.argv)
+def do_some_cmdline_options(argv):
+        if filter(lambda a, argv=argv: a in argv, ['-h', '--help']):
+            print """
+GNU Solfege %s
+Type "man solfege" for more details.
+Options:
+  --no-sound             Do not play any sounds. Useful when porting.
+  --verbose-sound-init   display more info about the sound setup
+  -v, --version
+  -w, --warranty         show warranty and copyright
+  -h, --help             Display this message
+  --gtk-help             Display the usual gtk/gnome commandline options.
+    """ % configureoutput.VERSION_STRING
+            sys.exit()
+
+        if filter(lambda a, argv=argv: a in argv, ['-v', '--version']):
+            print """GNU Solfege %s
+This is free software. It is covered by the GNU General Public License,
+and you are welcome to change it and/or distribute copies of it under
+certain conditions. Invoke as `solfege --warranty` for more information.
+
+Copyright (c) 2000-2001 by Tom Cato Amundsen <tca@gnu.org>
+            """ % configureoutput.VERSION_STRING
+            sys.exit()
+
+        if filter(lambda a, argv=argv: a in argv, ['-w', '--warranty']):
+            print """GNU Solfege %s
+Copyright (c) 2000-2001 by Tom Cato Amundsen <tca@gnu.org>
+
+    This program is free software; you can redistribute it and/or
+modify it under the terms of the GNU General Public License version 2
+as published by the Free Software Foundation.
+
+    This program is distributed in the hope that it will be useful,
+but WITHOUT ANY WARRANTY; without even the implied warranty of
+MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+General Public License for more details.
+
+    You should have received a copy (refer to the file COPYING) of the
+GNU General Public License along with this program; if not, write to
+the Free Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139,
+USA.
+        """ % configureoutput.VERSION_STRING
+            sys.exit()
+
+
+do_some_cmdline_options(sys.argv)
 
 if '--gtk-help' in sys.argv:
     del sys.argv[sys.argv.index('--gtk-help')]
@@ -70,7 +117,9 @@ for a in ('--no-sound', '--verbose-sound-init'):
         args.append(a)
         del sys.argv[sys.argv.index(a)]
 
-import GDK, os, gnome.ui, const, string
+import gnome, gnome.ui
+import GDK, os, const, string
+import app
 from htmlwidget import HtmlWidget
 import utils, history
 from configwindow import ConfigWindow
