@@ -15,7 +15,7 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
-import gu, const, soundcard, mpd
+import gu, const, soundcard, mpd, mpd.musicdisplayer
 from i18n import _
 import abstract, gtk
 import random
@@ -63,7 +63,7 @@ class Gui(abstract.Gui):
                                'play_first_note_ak': self.m_t.play_question,
                                'play_last_note_ak': self.m_t.play_last_note,
                                'play_all_ak': self.m_t.play_all_notes}
-        self.g_music_displayer = mpd.MusicDisplayer()
+        self.g_music_displayer = mpd.musicdisplayer.MusicDisplayer()
         self.g_music_displayer.clear()
         self.g_music_displayer.set_policy(gtk.POLICY_NEVER, gtk.POLICY_NEVER)
         self.practise_box.pack_start(self.g_music_displayer)
